;; Check ASCII optimizing decoder

(defvar test-file-list
  '(("~/tag-utf-8-unix.unix" ";; -*- coding: utf-8-unix; -*-" unix)
    ("~/tag-utf-8.unix" ";; -*- coding: utf-8; -*-" unix)
    ("~/tag-none.unix" "" unix)
    ("~/tag-utf-8-dos.dos" ";; -*- coding: utf-8-dos; -*-" dos)
    ("~/tag-utf-8.dos" ";; -*- coding: utf-8; -*-" dos)
    ("~/tag-none.dos" "" dos)))

(defun generate-test-file ()
  (interactive)
  (with-temp-buffer
    (message "Generating data...")
    (dotimes (i 100000)
      (insert-char ?a 80)
      (insert "\n"))
    (goto-char (point-min))
    (dolist (file test-file-list)
      (message "Writing %s..." (car file))
      (insert (nth 1 file) "\n")
      (let ((coding-system-for-write (nth 2 file)))
	(write-region (point-min) (point-max) (car file)))
      (delete-region (point-min) (point)))))

(defun benchmark-decoder ()
  (insert "With optimization:\n")
  (let ((gc-cons-threshold 4000000))
    (dolist (file test-file-list)
      (let ((result (benchmark-run 10
		      (with-temp-buffer (insert-file-contents (car file))))))
	(insert (format "%s: %s\n" (car file) result))))
    (insert "Without optimization:\n")
    (dolist (file test-file-list)
      (let* ((disable-ascii-optimization t)
	     (result (benchmark-run 10
		       (with-temp-buffer (insert-file-contents (car file))))))
	(insert (format "%s: %s\n"  (car file) result))))))
